@@ -207,10 +207,66 @@ global_helpers["re_match_groups"] = re_match_groups_helper
 
 
 
-def build_dict_helper(s):
-    """Helper function to build a dictionary from a string: the lines
-    of the string are parsed in the form 'key:value' and used to
-    populate a dictionary that is returned.
+def to_list_helper(s):
+    """Helper function to make a list from the lines in a multiline
+    string: each line is added as an item to the list.
+
+    Blank lines (including ones consiting entirely of spaces) are
+    skipped, as well as leading and trailing spaces on the remaining
+    lines.
+
+    The function is useful to get more complex data structures back
+    from Jinja2 macros (which can only return text).
+    """
+
+    l = []
+
+    for i in s.split("\n"):
+        i = i.strip()
+        
+        # only add to the list, if the line is not blank
+        if i:
+            l.append(i)
+
+    return l
+
+
+global_helpers["to_list"] = to_list_helper
+
+
+
+def to_set_helper(s):
+    """Helper function to make a set from the lines in a multiline
+    string: each line is added as an item to the list.
+
+    Blank lines (including ones consiting entirely of spaces) are
+    skipped, as well as leading and trailing spaces on the remaining
+    lines.
+
+    The function is useful to get more complex data structures back
+    from Jinja2 macros (which can only return text).
+    """
+
+    t = set()
+
+    for i in s.split("\n"):
+        i = i.strip()
+        
+        # only add to the list, if the line is not blank
+        if i:
+            t.add(i)
+
+    return t
+
+
+global_helpers["to_set"] = to_set_helper
+
+
+
+def to_dict_helper(s):
+    """Helper function to make a dictionary from a string: the lines of
+    the string are parsed in the form 'key:value' and used to populate
+    a dictionary that is returned.
 
     Blank lines (including ones consisting entirely of spaces) are
     skipped, as well as leading and trailing spaces in the key and value.
@@ -237,35 +293,7 @@ def build_dict_helper(s):
     return d
 
 
-global_helpers["build_dict"] = build_dict_helper
-
-
-
-def build_list_helper(s):
-    """Helper function to build a list from the lines in a multiline
-    string: each line is added as an item to the list.
-
-    Blank lines (including ones consiting entirely of spaces) are
-    skipped, as well as leading and trailing spaces on the remaining
-    lines.
-
-    The function is useful to get more complex data structures back
-    from Jinja2 macros (which can only return text).
-    """
-
-    l = []
-
-    for i in s.split("\n"):
-        i = i.strip()
-        
-        # only add to the list, if the line is not blank
-        if i:
-            l.append(i)
-
-    return l
-
-
-global_helpers["build_list"] = build_list_helper
+global_helpers["to_dict"] = to_dict_helper
 
 
 
